@@ -2,20 +2,22 @@ import asyncio
 import socket
 from functools import partial
 
+from ..utils import OptionsType, awaitable, bind_socket
 from .base import SimpleServer
-from ..utils import OptionsType, bind_socket
 
 
 class TCPServer(SimpleServer):
-    PROTO_NAME = 'tcp'
+    PROTO_NAME = "tcp"
 
-    def __init__(self, address: str = None, port: int = None,
-                 options: OptionsType = (), sock=None, **kwargs):
+    def __init__(
+        self, address: str = None, port: int = None,
+        options: OptionsType = (), sock=None, **kwargs
+    ):
         if not sock:
             if not (address and port):
                 raise RuntimeError(
-                    'You should pass socket instance or '
-                    '"address" and "port" couple'
+                    "You should pass socket instance or "
+                    '"address" and "port" couple',
                 )
 
             self.make_socket = partial(
@@ -25,7 +27,7 @@ class TCPServer(SimpleServer):
                 options=options,
             )
         elif not isinstance(sock, socket.socket):
-            raise ValueError('sock must be socket instance')
+            raise ValueError("sock must be socket instance")
         else:
             self.make_socket = lambda: sock
 
@@ -33,14 +35,22 @@ class TCPServer(SimpleServer):
 
         super().__init__(**kwargs)
 
-    async def handle_client(self, reader: asyncio.StreamReader,
-                            writer: asyncio.StreamWriter):
+    async def handle_client(
+        self, reader: asyncio.StreamReader,
+        writer: asyncio.StreamWriter
+    ):
         raise NotImplementedError
 
+    def make_client_handler(
+        self, reader: asyncio.StreamReader,
+        writer: asyncio.StreamWriter,
+    ):
+        return self.create_task(awaitable(self.handle_client)(reader, writer))
+
     async def start(self):
         self.socket = self.make_socket()
         self.server = await asyncio.start_server(
-            self.handle_client,
+            self.make_client_handler,
             sock=self.socket,
         )
 
