@@ -2,15 +2,16 @@ import asyncio
 import socket
 from functools import partial
 
+from ..utils import OptionsType, awaitable, bind_socket
 from .base import SimpleServer
-from ..utils import OptionsType, bind_socket, awaitable
 
 
 class UDPServer(SimpleServer):
     class UDPSimpleProtocol(asyncio.DatagramProtocol):
 
-        def __init__(self, handle_datagram):
+        def __init__(self, handle_datagram, task_factory):
             super().__init__()
+            self.task_factory = task_factory
             self.handler = awaitable(handle_datagram)
             self.transport = None  # type: asyncio.DatagramTransport
             self.loop = None  # type: asyncio.AbstractEventLoop
@@ -20,26 +21,28 @@ class UDPServer(SimpleServer):
             self.loop = asyncio.get_event_loop()
 
         def datagram_received(self, data: bytes, addr: tuple):
-            self.loop.create_task(self.handler(data, addr))
+            self.task_factory(self.handler(data, addr))
 
-    def __init__(self, address: str = None, port: int = None,
-                 options: OptionsType = (), sock=None, **kwargs):
+    def __init__(
+        self, address: str = None, port: int = None,
+        options: OptionsType = (), sock=None, **kwargs
+    ):
         if not sock:
             if not (address and port):
                 raise RuntimeError(
-                    'You should pass socket instance or '
-                    '"address" and "port" couple'
+                    "You should pass socket instance or "
+                    '"address" and "port" couple',
                 )
 
             self.make_socket = partial(
                 bind_socket,
-                socket.AF_INET6 if ':' in address else socket.AF_INET,
+                socket.AF_INET6 if ":" in address else socket.AF_INET,
                 socket.SOCK_DGRAM,
                 address=address, port=port, options=options,
-                proto_name='udp',
+                proto_name="udp",
             )
         elif not isinstance(sock, socket.socket):
-            raise ValueError('sock must be socket instance')
+            raise ValueError("sock must be socket instance")
         else:
             self.make_socket = lambda: sock
 
@@ -55,6 +58,9 @@ class UDPServer(SimpleServer):
         self.socket = self.make_socket()
 
         self.server, self._protocol = await self.loop.create_datagram_endpoint(
-            lambda: UDPServer.UDPSimpleProtocol(self.handle_datagram),
+            lambda: UDPServer.UDPSimpleProtocol(
+                self.handle_datagram,
+                self.create_task,
+            ),
             sock=self.socket,
         )
